@@ -1,6 +1,6 @@
 package POE::Component::Resolver;
 BEGIN {
-  $POE::Component::Resolver::VERSION = '0.912';
+  $POE::Component::Resolver::VERSION = '0.913';
 }
 
 use warnings;
@@ -12,6 +12,8 @@ use Time::HiRes qw(time);
 use Socket qw(unpack_sockaddr_in AF_INET AF_INET6);
 use Socket::GetAddrInfo qw(:newapi getnameinfo NI_NUMERICHOST NI_NUMERICSERV);
 
+use POE::Component::Resolver::Sidecar;
+
 use Exporter;
 use base 'Exporter';
 our (@EXPORT_OK) = qw(AF_INET AF_INET6);
@@ -24,8 +26,9 @@ sub new {
 	croak "new() requires an even number of parameters" if @args % 2;
 	my %args = @args;
 
-	my $max_resolvers = delete($args{max_resolvers}) || 8;
-	my $idle_timeout  = delete($args{idle_timeout})  || 15;
+	my $max_resolvers   = delete($args{max_resolvers}) || 8;
+	my $idle_timeout    = delete($args{idle_timeout})  || 15;
+	my $sidecar_program = delete($args{sidecar_program});
 
 	my $af_order = delete($args{af_order});
 	if (defined $af_order and @$af_order) {
@@ -48,6 +51,20 @@ sub new {
 	my @error = sort keys %args;
 	croak "unknown new() parameter(s): @error" if @error;
 
+	unless (defined $sidecar_program and length $sidecar_program) {
+		if ($^O eq "MSWin32") {
+			$sidecar_program = \&POE::Component::Resolver::Sidecar::main;
+		}
+		else {
+			$sidecar_program = [
+				$^X,
+				(map { "-I$_" } @INC),
+				'-MPOE::Component::Resolver::Sidecar',
+				'-e', 'POE::Component::Resolver::Sidecar->main()'
+			];
+		}
+	}
+
 	my $self = bless { }, $class;
 
 	POE::Session->create(
@@ -73,6 +90,7 @@ sub new {
 			max_resolvers   => $max_resolvers,
 			requests        => { },
 			sidecar_ring    => [ ],
+			sidecar_program => $sidecar_program,
 		}
 	);
 
@@ -192,17 +210,7 @@ sub _poe_setup_sidecar_ring {
 			StdoutEvent  => 'sidecar_response',
 			StderrEvent  => 'sidecar_error',
 			CloseEvent   => 'sidecar_closed',
-			Program      => (
-				($^O eq "MSWin32")
-				? \&POE::Component::Resolver::Sidecar::main
-				: [
-					$^X,
-					(map { "-I$_" } @INC),
-					'-MPOE::Component::Resolver::Sidecar',
-					'-e',
-					'POE::Component::Resolver::Sidecar->main()'
-				]
-			),
+			Program      => $heap->{sidecar_program},
 		);
 
 		$heap->{sidecar}{$sidecar->PID}   = $sidecar;
@@ -428,7 +436,7 @@ POE::Component::Resolver - A non-blocking getaddrinfo() resolver
 
 =head1 VERSION
 
-version 0.912
+version 0.913
 
 =head1 SYNOPSIS
 
@@ -444,6 +452,7 @@ version 0.912
 		max_resolvers => 8,
 		idle_timeout  => 5,
 		af_order      => [ AF_INET6, AF_INET ],
+		# sidecar_program => $path_to_program,
 	);
 
 	my @hosts = qw( ipv6-test.com );
@@ -496,7 +505,7 @@ can be overridden with constructor parameters.
 Create a new resolver.  Returns an object that must be held and used
 to make requests.  See the synopsis.
 
-Accepts up to two optional named parameters.
+Accepts up to four optional named parameters.
 
 "af_order" may contain an arrayref with the address families to
 permit, in the order in which they're preferred.  Without "af_order",
@@ -524,6 +533,17 @@ you have available and the amount of parallelism you require.
 	# One at a time, but without the pesky blocking.
 	my $r3 = POE::Component::Resolver->new( max_resolvers => 1 );
 
+"sidecar_program" contains the disk location of a program that will
+perform blocking lookups on standard input and print the results on
+standard output.  The sidecar program is needed only in special
+environments where the bundling and execution of extra utilities is
+tricky.  PAR is one such environment.
+
+The sidecar program needs to contain at least two statements:
+
+	use POE::Component::Resolver::Sidecar;
+	POE::Component::Resover::Sidecar->main();
+
 =head3 resolve
 
 resolve() begins a new request to resolve a domain.  The request will
@@ -674,4 +694,4 @@ Rocco Caputo.  All rights reserved.  This distribution is free
 software; you may redistribute it and/or modify it under the same
 terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
